@@ -17,7 +17,6 @@ from .core.CartographySelector import CartographySelector
 from .core.CrossFader import CrossFader
 from .core.Fader import Fader
 from .core.GeneticAlgorithm import GeneticAlgorithm
-from .core.GeneticAlgorithmMusicMaker import GeneticAlgorithmMusicMaker
 from .core.Hocketer import Hocketer
 from .core.LeafLooper import LeafLooper
 from .core.ListLooper import ListLooper
@@ -30,13 +29,13 @@ from .core.WindowLooper import WindowLooper
 
 from .indicators.TimeSignature import TimeSignature
 
+from .makers.GeneticAlgorithmMusicMaker import GeneticAlgorithmMusicMaker
 from .makers.LeafDynMaker import LeafDynMaker
 
 from .score.ArtificialHarmonic import ArtificialHarmonic
 from .score.HarmonicNote import HarmonicNote
 from .score.Score import Score
 
-from .spanners.half_piano_pedal import half_piano_pedal
 from .spanners.piano_pedal import piano_pedal
 
 from .utilities.staff_splitter import staff_splitter
@@ -47,7 +46,7 @@ from . import mutate
 
 
 __author__ = "Gilberto Agostinho <gilbertohasnofb@gmail.com>"
-__version__ = "0.9.2"
+__version__ = "0.9.6"
 __all__ = [
     '__author__',
     '__version__',
@@ -55,8 +54,8 @@ __all__ = [
     'CrossFader',
     'Fader',
     'GeneticAlgorithm',
-    'GeneticAlgorithmMusicMaker',
     'Hocketer',
+    'GeneticAlgorithmMusicMaker',
     'LeafLooper',
     'ListLooper',
     'Phaser',
@@ -70,7 +69,6 @@ __all__ = [
     'ArtificialHarmonic',
     'HarmonicNote',
     'Score',
-    'half_piano_pedal',
     'piano_pedal',
     'staff_splitter',
     'get',
