@@ -16,6 +16,19 @@ class Shuffler:
         container.
 
         >>> container = abjad.Container(r"c'4 d'4 e'4 f'4")
+        >>> abjad.show(container)
+
+        ..  docs::
+
+            {
+                c'4
+                d'4
+                e'4
+                f'4
+            }
+
+        ..  figure:: ../_images/Shuffler-1oLQZeQNPo.png
+
         >>> shuffler = auxjad.Shuffler(container)
         >>> notes = shuffler()
         >>> staff = abjad.Staff(notes)
@@ -958,9 +971,7 @@ class Shuffler:
 
         ..  docs::
 
-            \new Staff
             {
-                \time 4/4
                 e'16
                 f'8.
                 ~
@@ -1440,7 +1451,7 @@ class Shuffler:
         return self.__repr__()
 
     @staticmethod
-    def _get_logical_selections(container) -> None:
+    def _get_logical_selections(container) -> abjad.Selection:
         r'Updates the selection of logical ties of a container.'
         def group_logical_ties(logical_tie):
             if isinstance(logical_tie.head, abjad.Rest):
