@@ -7,8 +7,11 @@ import auxjad
 
 
 def test_WindowLooper_01():
-    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
-    looper = auxjad.WindowLooper(container)
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'4.")
+    looper = auxjad.WindowLooper(container,
+                                 window_size=(4, 4),
+                                 step_size=(1, 16),
+                                 )
     assert abjad.lilypond(looper) == abjad.String.normalize(
         r"""
         {
@@ -18,9 +21,10 @@ def test_WindowLooper_01():
             f'2
             ~
             f'8
-            g'1
+            g'4.
         }
-        """)
+        """
+    )
     notes = looper()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -32,7 +36,8 @@ def test_WindowLooper_01():
             d'2
             e'4
         }
-        """)
+        """
+    )
     notes = looper()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -51,7 +56,8 @@ def test_WindowLooper_01():
             e'8.
             f'16
         }
-        """)
+        """
+    )
     notes = looper.current_window
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -70,11 +76,12 @@ def test_WindowLooper_01():
             e'8.
             f'16
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_02():
-    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'4.")
     looper = auxjad.WindowLooper(container,
                                  window_size=(3, 4),
                                  step_size=(1, 8),
@@ -89,7 +96,8 @@ def test_WindowLooper_02():
             c'4
             d'2
         }
-        """)
+        """
+    )
     notes = looper()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -103,7 +111,8 @@ def test_WindowLooper_02():
             d'4.
             e'8
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_03():
@@ -122,7 +131,8 @@ def test_WindowLooper_03():
             c'4
             d'2
         }
-        """)
+        """
+    )
     notes = looper.__next__()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -136,7 +146,8 @@ def test_WindowLooper_03():
             d'4.
             e'8
         }
-        """)
+        """
+    )
     notes = looper.__next__()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -147,7 +158,8 @@ def test_WindowLooper_03():
             d'2
             e'4
         }
-        """)
+        """
+    )
     notes = looper.__next__()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -159,7 +171,8 @@ def test_WindowLooper_03():
             e'4
             r8
         }
-        """)
+        """
+    )
     notes = looper.__next__()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -171,7 +184,8 @@ def test_WindowLooper_03():
             e'4
             r4
         }
-        """)
+        """
+    )
     notes = looper.__next__()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -183,7 +197,8 @@ def test_WindowLooper_03():
             e'4
             r4.
         }
-        """)
+        """
+    )
     notes = looper.__next__()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -194,7 +209,8 @@ def test_WindowLooper_03():
             e'4
             r2
         }
-        """)
+        """
+    )
     notes = looper.__next__()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -206,13 +222,14 @@ def test_WindowLooper_03():
             r8
             r2
         }
-        """)
+        """
+    )
     with pytest.raises(StopIteration):
-        assert looper.__next__()
+        notes = looper.__next__()  # noqa: F841
 
 
 def test_WindowLooper_04():
-    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'4.")
     looper = auxjad.WindowLooper(container,
                                  window_size=(3, 4),
                                  step_size=(5, 8),
@@ -226,6 +243,9 @@ def test_WindowLooper_04():
                                  maximum_dot_count=1,
                                  rewrite_tuplets=False,
                                  process_on_first_call=True,
+                                 after_rest=(1, 8),
+                                 after_rest_in_new_measure=True,
+                                 use_multimeasure_rests=False,
                                  )
     assert looper.window_size == abjad.Meter((3, 4))
     assert looper.step_size == abjad.Duration((5, 8))
@@ -239,6 +259,9 @@ def test_WindowLooper_04():
     assert looper.maximum_dot_count == 1
     assert not looper.rewrite_tuplets
     assert looper.process_on_first_call
+    assert looper.after_rest == abjad.Duration((1, 8))
+    assert looper.after_rest_in_new_measure
+    assert not looper.use_multimeasure_rests
     looper.window_size = (5, 4)
     looper.step_size = (1, 4)
     looper.max_steps = 3
@@ -251,6 +274,9 @@ def test_WindowLooper_04():
     looper.maximum_dot_count = 2
     looper.rewrite_tuplets = True
     looper.process_on_first_call = False
+    looper.after_rest = 0
+    looper.after_rest_in_new_measure = False
+    looper.use_multimeasure_rests = True
     assert looper.window_size == abjad.Meter((5, 4))
     assert looper.step_size == abjad.Duration((1, 4))
     assert looper.max_steps == 3
@@ -263,6 +289,9 @@ def test_WindowLooper_04():
     assert looper.maximum_dot_count == 2
     assert looper.rewrite_tuplets
     assert not looper.process_on_first_call
+    assert looper.after_rest == abjad.Duration(0)
+    assert not looper.after_rest_in_new_measure
+    assert looper.use_multimeasure_rests
 
 
 def test_WindowLooper_05():
@@ -290,12 +319,16 @@ def test_WindowLooper_05():
             f'4
             r2
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_06():
-    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
-    looper = auxjad.WindowLooper(container)
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'4.")
+    looper = auxjad.WindowLooper(container,
+                                 window_size=(4, 4),
+                                 step_size=(1, 16),
+                                 )
     notes = looper.__next__()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -307,7 +340,8 @@ def test_WindowLooper_06():
             d'2
             e'4
         }
-        """)
+        """
+    )
     notes = looper.__next__()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -326,7 +360,8 @@ def test_WindowLooper_06():
             e'8.
             f'16
         }
-        """)
+        """
+    )
     notes = looper.__next__()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -343,7 +378,8 @@ def test_WindowLooper_06():
             e'4
             f'8
         }
-        """)
+        """
+    )
     looper.window_size = (3, 8)
     notes = looper.__next__()
     staff = abjad.Staff(notes)
@@ -357,7 +393,8 @@ def test_WindowLooper_06():
             ~
             d'4
         }
-        """)
+        """
+    )
     notes = looper.__next__()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -367,7 +404,8 @@ def test_WindowLooper_06():
             \time 3/8
             d'4.
         }
-        """)
+        """
+    )
     notes = looper.__next__()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -377,7 +415,8 @@ def test_WindowLooper_06():
             \time 3/8
             d'4.
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_07():
@@ -420,12 +459,17 @@ def test_WindowLooper_07():
             ~
             d'2
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_08():
-    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
-    looper = auxjad.WindowLooper(container, omit_time_signatures=True)
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'4.")
+    looper = auxjad.WindowLooper(container,
+                                 window_size=(4, 4),
+                                 step_size=(1, 16),
+                                 omit_time_signatures=True,
+                                 )
     notes = looper()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -436,30 +480,91 @@ def test_WindowLooper_08():
             d'2
             e'4
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_09():
     wrong_type_input = 'foobar'
-    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'4.")
     with pytest.raises(TypeError):
-        assert auxjad.WindowLooper(wrong_type_input)
-        assert auxjad.WindowLooper(container, window_size=17j)
-        assert auxjad.WindowLooper(container, step_size=True)
-        assert auxjad.WindowLooper(container, max_steps='foo')
-        assert auxjad.WindowLooper(container, repetition_chance='bar')
-        assert auxjad.WindowLooper(container, forward_bias=False)
-        assert auxjad.WindowLooper(container, head_position=62.3j)
-        assert auxjad.WindowLooper(container, omit_time_signatures='xyz')
-        assert auxjad.WindowLooper(container, fill_with_rests=1.2)
+        looper = auxjad.WindowLooper(wrong_type_input,  # noqa: F841
+                                     window_size=(4, 4),
+                                     step_size=(1, 16),
+                                     )
+        looper = auxjad.WindowLooper(container,  # noqa: F841
+                                     window_size=17j,
+                                     step_size=(1, 16),
+                                     )
+        looper = auxjad.WindowLooper(container,  # noqa: F841
+                                     window_size=(4, 4),
+                                     step_size=True,
+                                     )
+        looper = auxjad.WindowLooper(container,  # noqa: F841
+                                     window_size=(4, 4),
+                                     step_size=(1, 16),
+                                     max_steps='foo',
+                                     )
+        looper = auxjad.WindowLooper(container,  # noqa: F841
+                                     window_size=(4, 4),
+                                     step_size=(1, 16),
+                                     repetition_chance='bar',
+                                     )
+        looper = auxjad.WindowLooper(container,  # noqa: F841
+                                     window_size=(4, 4),
+                                     step_size=(1, 16),
+                                     forward_bias=False,
+                                     )
+        looper = auxjad.WindowLooper(container,  # noqa: F841
+                                     window_size=(4, 4),
+                                     step_size=(1, 16),
+                                     head_position=62.3j,
+                                     )
+        looper = auxjad.WindowLooper(container,  # noqa: F841
+                                     window_size=(4, 4),
+                                     step_size=(1, 16),
+                                     omit_time_signatures='xyz',
+                                     )
+        looper = auxjad.WindowLooper(container,  # noqa: F841
+                                     window_size=(4, 4),
+                                     step_size=(1, 16),
+                                     fill_with_rests=1.2,
+                                     )
     with pytest.raises(ValueError):
-        assert auxjad.WindowLooper(container, window_size=(100, 1))
-        assert auxjad.WindowLooper(container, max_steps=-1)
-        assert auxjad.WindowLooper(container, repetition_chance=-0.3)
-        assert auxjad.WindowLooper(container, repetition_chance=1.4)
-        assert auxjad.WindowLooper(container, forward_bias=-0.3)
-        assert auxjad.WindowLooper(container, forward_bias=1.4)
-        assert auxjad.WindowLooper(container, head_position=(100, 1))
+        looper = auxjad.WindowLooper(container,  # noqa: F841
+                                     window_size=(100, 1),
+                                     step_size=(1, 16),
+                                     )
+        looper = auxjad.WindowLooper(container,  # noqa: F841
+                                     window_size=(4, 4),
+                                     step_size=(1, 16),
+                                     max_steps=-1,
+                                     )
+        looper = auxjad.WindowLooper(container,  # noqa: F841
+                                     window_size=(4, 4),
+                                     step_size=(1, 16),
+                                     repetition_chance=-0.3,
+                                     )
+        looper = auxjad.WindowLooper(container,  # noqa: F841
+                                     window_size=(4, 4),
+                                     step_size=(1, 16),
+                                     repetition_chance=1.4,
+                                     )
+        looper = auxjad.WindowLooper(container,  # noqa: F841
+                                     window_size=(4, 4),
+                                     step_size=(1, 16),
+                                     forward_bias=-0.3,
+                                     )
+        looper = auxjad.WindowLooper(container,  # noqa: F841
+                                     window_size=(4, 4),
+                                     step_size=(1, 16),
+                                     forward_bias=1.4,
+                                     )
+        looper = auxjad.WindowLooper(container,  # noqa: F841
+                                     window_size=(4, 4),
+                                     step_size=(1, 16),
+                                     head_position=(100, 1),
+                                     )
 
 
 def test_WindowLooper_10():
@@ -491,7 +596,8 @@ def test_WindowLooper_10():
             f'4
             r2
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_11():
@@ -525,7 +631,8 @@ def test_WindowLooper_11():
             f'4
             r2
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_12():
@@ -548,7 +655,8 @@ def test_WindowLooper_12():
             e'4
             f'4
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_13():
@@ -570,7 +678,8 @@ def test_WindowLooper_13():
             d'2
             e'4
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_14():
@@ -580,7 +689,7 @@ def test_WindowLooper_14():
                                  step_size=(1, 4),
                                  )
     with pytest.raises(RuntimeError):
-        looper.output_n(100)
+        notes = looper.output_n(100)  # noqa: F841
 
 
 def test_WindowLooper_15():
@@ -608,7 +717,8 @@ def test_WindowLooper_15():
             e'4
             f'4
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_16():
@@ -639,7 +749,8 @@ def test_WindowLooper_16():
             d'4
             e'4
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_17():
@@ -660,12 +771,15 @@ def test_WindowLooper_17():
             d'4
             e'4
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_18():
-    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'4.")
     looper = auxjad.WindowLooper(container,
+                                 window_size=(4, 4),
+                                 step_size=(1, 16),
                                  process_on_first_call=True,
                                  )
     notes = looper()
@@ -686,12 +800,16 @@ def test_WindowLooper_18():
             e'8.
             f'16
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_19():
     container = abjad.Container(r"c'4-.\p\< d'2--\f e'4->\ppp f'2 ~ f'8")
-    looper = auxjad.WindowLooper(container)
+    looper = auxjad.WindowLooper(container,
+                                 window_size=(4, 4),
+                                 step_size=(1, 16),
+                                 )
     staff = abjad.Staff()
     notes = looper.output_n(2)
     staff = abjad.Staff(notes)
@@ -728,12 +846,16 @@ def test_WindowLooper_19():
             e'8.
             f'16
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_20():
-    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
-    looper = auxjad.WindowLooper(container)
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'4.")
+    looper = auxjad.WindowLooper(container,
+                                 window_size=(4, 4),
+                                 step_size=(1, 16),
+                                 )
     notes = looper()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -745,7 +867,8 @@ def test_WindowLooper_20():
             d'2
             e'4
         }
-        """)
+        """
+    )
     notes = looper()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -764,7 +887,8 @@ def test_WindowLooper_20():
             e'8.
             f'16
         }
-        """)
+        """
+    )
     looper.contents = abjad.Container(r"c'16 d'16 e'16 f'16 g'2. | a'1")
     notes = looper()
     staff = abjad.Staff(notes)
@@ -783,7 +907,8 @@ def test_WindowLooper_20():
             g'8.
             a'16
         }
-        """)
+        """
+    )
     looper.head_position = 0
     notes = looper()
     staff = abjad.Staff(notes)
@@ -798,22 +923,27 @@ def test_WindowLooper_20():
             f'16
             g'2.
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_21():
     container = abjad.Container(r"c'1")
-    looper = auxjad.WindowLooper(container)
+    looper = auxjad.WindowLooper(container,
+                                 window_size=(4, 4),
+                                 step_size=(1, 16),
+                                 )
     assert len(looper) == 16
     container = abjad.Container(r"c'1")
     looper = auxjad.WindowLooper(container,
+                                 window_size=(4, 4),
                                  step_size=(1, 4),
                                  )
     assert len(looper) == 4
     container = abjad.Container(r"c'2..")
     looper = auxjad.WindowLooper(container,
-                                 step_size=(1, 4),
                                  window_size=(2, 4),
+                                 step_size=(1, 4),
                                  )
     assert len(looper) == 4
 
@@ -839,7 +969,8 @@ def test_WindowLooper_22():
             e'4
             f'4
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_23():
@@ -874,14 +1005,17 @@ def test_WindowLooper_23():
             e'4
             f'4
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_24():
-    random.seed(19814)
-    container = abjad.Container(r"c'4 d'4 e'4 f'4 g'4 a'4 b'4 c''4")
+    random.seed(81723)
+    container = abjad.Container(
+        r"c'4 d'4 e'4 f'4 g'4 a'4 b'4 c''4 d''4 e''4 f''4"
+    )
     looper = auxjad.WindowLooper(container,
-                                 window_size=(1, 4),
+                                 window_size=(3, 4),
                                  step_size=(1, 4),
                                  max_steps=4,
                                  )
@@ -891,18 +1025,30 @@ def test_WindowLooper_24():
         r"""
         \new Staff
         {
-            \time 1/4
+            \time 3/4
             c'4
+            d'4
+            e'4
+            e'4
             f'4
-            b'4
+            g'4
+            f'4
+            g'4
+            a'4
             c''4
+            d''4
+            e''4
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_25():
     container = abjad.Container(r"c'4. d'8 e'2")
-    looper = auxjad.WindowLooper(container)
+    looper = auxjad.WindowLooper(container,
+                                 window_size=(4, 4),
+                                 step_size=(1, 16),
+                                 )
     notes = looper()
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -914,8 +1060,11 @@ def test_WindowLooper_25():
             d'8
             e'2
         }
-        """)
+        """
+    )
     looper = auxjad.WindowLooper(container,
+                                 window_size=(4, 4),
+                                 step_size=(1, 16),
                                  boundary_depth=1,
                                  )
     notes = looper()
@@ -931,7 +1080,8 @@ def test_WindowLooper_25():
             d'8
             e'2
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_26():
@@ -979,7 +1129,8 @@ def test_WindowLooper_26():
             r8
             r2
         }
-        """)
+        """
+    )
     auxjad.mutate.remove_repeated_time_signatures(staff[:])
     assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
@@ -1010,50 +1161,81 @@ def test_WindowLooper_26():
             r8
             r2
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_27():
     container = abjad.Container(r"c'4 d'4 e'4 f'4")
-    looper = auxjad.WindowLooper(container)
+    looper = auxjad.WindowLooper(container,
+                                 window_size=(4, 4),
+                                 step_size=(1, 16),
+                                 )
     assert isinstance(looper(), abjad.Selection)
     tuplet = abjad.Tuplet('3:2', r"c'2 d'2 e'2")
-    looper = auxjad.WindowLooper(tuplet)
+    looper = auxjad.WindowLooper(tuplet,
+                                 window_size=(4, 4),
+                                 step_size=(1, 16),
+                                 )
     assert isinstance(looper(), abjad.Selection)
     voice = abjad.Voice(r"c'4 d'4 e'4 f'4")
-    looper = auxjad.WindowLooper(voice)
+    looper = auxjad.WindowLooper(voice,
+                                 window_size=(4, 4),
+                                 step_size=(1, 16),
+                                 )
     assert isinstance(looper(), abjad.Selection)
     staff = abjad.Staff(r"c'4 d'4 e'4 f'4")
-    looper = auxjad.WindowLooper(staff)
+    looper = auxjad.WindowLooper(staff,
+                                 window_size=(4, 4),
+                                 step_size=(1, 16),
+                                 )
     assert isinstance(looper(), abjad.Selection)
     score = abjad.Score([abjad.Staff(r"c'4 d'4 e'4 f'4")])
-    looper = auxjad.WindowLooper(score)
+    looper = auxjad.WindowLooper(score,
+                                 window_size=(4, 4),
+                                 step_size=(1, 16),
+                                 )
     assert isinstance(looper(), abjad.Selection)
     voice = abjad.Voice(r"c'4 d'4 e'4 f'4")
     staff = abjad.Staff([voice])
-    looper = auxjad.WindowLooper(staff)
+    looper = auxjad.WindowLooper(staff,
+                                 window_size=(4, 4),
+                                 step_size=(1, 16),
+                                 )
     assert isinstance(looper(), abjad.Selection)
     staff = abjad.Staff(r"c'4 d'4 e'4 f'4")
     score = abjad.Score([staff])
-    looper = auxjad.WindowLooper(score)
+    looper = auxjad.WindowLooper(score,
+                                 window_size=(4, 4),
+                                 step_size=(1, 16),
+                                 )
     assert isinstance(looper(), abjad.Selection)
 
     voice1 = abjad.Voice(r"c'4 d'4 e'4 f'4")
     voice2 = abjad.Voice(r"g2 f2")
     staff = abjad.Staff([voice1, voice2], simultaneous=True)
     with pytest.raises(ValueError):
-        auxjad.WindowLooper(staff)
+        looper = auxjad.WindowLooper(staff,  # noqa: F841
+                                     window_size=(4, 4),
+                                     step_size=(1, 16),
+                                     )
 
     staff1 = abjad.Staff(r"c'4 d'4 e'4 f'4")
     staff2 = abjad.Staff(r"g2 f2")
     score = abjad.Score([staff1, staff2])
     with pytest.raises(ValueError):
-        auxjad.WindowLooper(score)
+        looper = auxjad.WindowLooper(score,  # noqa: F841
+                                     window_size=(4, 4),
+                                     step_size=(1, 16),
+                                     )
 
 
 def test_WindowLooper_28():
     container = abjad.Container(r"c'4.\p( d'8 e'8\f) f'4.\p( ~ f'4 g'1\pp)")
-    looper = auxjad.WindowLooper(container, step_size=(1, 4))
+    looper = auxjad.WindowLooper(container,
+                                 window_size=(4, 4),
+                                 step_size=(1, 4),
+                                 )
     notes = looper.output_n(6)
     staff = abjad.Staff(notes)
     assert abjad.lilypond(staff) == abjad.String.normalize(
@@ -1104,7 +1286,8 @@ def test_WindowLooper_28():
             )
             g'1
         }
-        """)
+        """
+    )
 
 
 def test_WindowLooper_29():
@@ -1132,7 +1315,8 @@ def test_WindowLooper_29():
             e'8.
             f'16
         }
-        """)
+        """
+    )
     container = abjad.Container(r"c'4 d'4 e'4 f'4 g'4")
     looper = auxjad.WindowLooper(container,
                                  window_size=(3, 4),
@@ -1154,4 +1338,160 @@ def test_WindowLooper_29():
             e'4
             f'16
         }
-        """)
+        """
+    )
+
+
+def test_WindowLooper_30():
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'4.")
+    looper = auxjad.WindowLooper(container,
+                                 window_size=(3, 4),
+                                 step_size=(1, 16),
+                                 after_rest=(1, 4),
+                                 )
+    notes = looper.output_n(3)
+    staff = abjad.Staff(notes)
+    assert abjad.lilypond(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \time 4/4
+            c'4
+            d'2
+            r4
+            c'8.
+            d'16
+            ~
+            d'4
+            ~
+            d'8.
+            e'16
+            r4
+            c'8
+            d'8
+            ~
+            d'4
+            ~
+            d'8
+            e'8
+            r4
+        }
+        """
+    )
+
+
+def test_WindowLooper_31():
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'4.")
+    looper = auxjad.WindowLooper(container,
+                                 window_size=(3, 4),
+                                 step_size=(1, 16),
+                                 after_rest=(1, 4),
+                                 after_rest_in_new_measure=True,
+                                 )
+    notes = looper.output_n(3)
+    staff = abjad.Staff(notes)
+    assert abjad.lilypond(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \time 3/4
+            c'4
+            d'2
+            \time 1/4
+            R1 * 1/4
+            \time 3/4
+            c'8.
+            d'16
+            ~
+            d'4..
+            e'16
+            \time 1/4
+            R1 * 1/4
+            \time 3/4
+            c'8
+            d'8
+            ~
+            d'4.
+            e'8
+            \time 1/4
+            R1 * 1/4
+        }
+        """
+    )
+
+
+def test_WindowLooper_32():
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'4.")
+    looper = auxjad.WindowLooper(container,
+                                 window_size=(3, 4),
+                                 step_size=(1, 16),
+                                 after_rest=(1, 4),
+                                 after_rest_in_new_measure=True,
+                                 use_multimeasure_rests=False,
+                                 )
+    notes = looper.output_n(3)
+    staff = abjad.Staff(notes)
+    assert abjad.lilypond(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \time 3/4
+            c'4
+            d'2
+            \time 1/4
+            r4
+            \time 3/4
+            c'8.
+            d'16
+            ~
+            d'4..
+            e'16
+            \time 1/4
+            r4
+            \time 3/4
+            c'8
+            d'8
+            ~
+            d'4.
+            e'8
+            \time 1/4
+            r4
+        }
+        """
+    )
+
+
+def test_WindowLooper_33():
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'4.")
+    looper = auxjad.WindowLooper(container,
+                                 window_size=(3, 4),
+                                 step_size=(1, 16),
+                                 after_rest=(1, 4),
+                                 after_rest_in_new_measure=True,
+                                 use_multimeasure_rests=True,
+                                 omit_time_signatures=True,
+                                 )
+    notes = looper.output_n(3)
+    staff = abjad.Staff(notes)
+    assert abjad.lilypond(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            c'4
+            d'2
+            r4
+            c'8.
+            d'16
+            ~
+            d'4..
+            e'16
+            r4
+            c'8
+            d'8
+            ~
+            d'4.
+            e'8
+            r4
+        }
+        """
+    )
