@@ -26,7 +26,8 @@ def test_staff_splitter_01():
                 r2
             }
         >>
-        """)
+        """
+    )
 
 
 def test_staff_splitter_02():
@@ -54,7 +55,8 @@ def test_staff_splitter_02():
                 <f a>4
             }
         >>
-        """)
+        """
+    )
 
 
 def test_staff_splitter_03():
@@ -97,7 +99,8 @@ def test_staff_splitter_03():
                 }
             }
         >>
-        """)
+        """
+    )
 
 
 def test_staff_splitter_04():
@@ -124,7 +127,8 @@ def test_staff_splitter_04():
                 d'4
             }
         >>
-        """)
+        """
+    )
     staves = auxjad.staff_splitter(staff, threshold='E4')
     score = abjad.Score(staves)
     assert abjad.lilypond(score) == abjad.String.normalize(
@@ -147,7 +151,8 @@ def test_staff_splitter_04():
                 d'4
             }
         >>
-        """)
+        """
+    )
     staves = auxjad.staff_splitter(staff, threshold=abjad.NamedPitch("e'"))
     score = abjad.Score(staves)
     assert abjad.lilypond(score) == abjad.String.normalize(
@@ -170,7 +175,8 @@ def test_staff_splitter_04():
                 d'4
             }
         >>
-        """)
+        """
+    )
     staves = auxjad.staff_splitter(staff, threshold=abjad.NumberedPitch(4))
     score = abjad.Score(staves)
     assert abjad.lilypond(score) == abjad.String.normalize(
@@ -193,7 +199,8 @@ def test_staff_splitter_04():
                 d'4
             }
         >>
-        """)
+        """
+    )
     staves = auxjad.staff_splitter(staff, threshold=4)
     score = abjad.Score(staves)
     assert abjad.lilypond(score) == abjad.String.normalize(
@@ -216,7 +223,8 @@ def test_staff_splitter_04():
                 d'4
             }
         >>
-        """)
+        """
+    )
 
 
 def test_staff_splitter_05():
@@ -246,7 +254,8 @@ def test_staff_splitter_05():
                 d'4
             }
         >>
-        """)
+        """
+    )
 
 
 def test_staff_splitter_06():
@@ -276,7 +285,8 @@ def test_staff_splitter_06():
                 f4
             }
         >>
-        """)
+        """
+    )
 
 
 def test_staff_splitter_07():
@@ -304,7 +314,8 @@ def test_staff_splitter_07():
                 d'4
             }
         >>
-        """)
+        """
+    )
 
 
 def test_staff_splitter_08():
@@ -349,7 +360,8 @@ def test_staff_splitter_08():
                 }
             }
         >>
-        """)
+        """
+    )
 
 
 def test_staff_splitter_09():
@@ -400,7 +412,8 @@ def test_staff_splitter_09():
                 }
             }
         >>
-        """)
+        """
+    )
     staff = abjad.Staff(
         r"c'2\p <b d'>2\ff \times 2/3 {<g b d'>2\f <e' f'>1\mf}"
         r"\times 2/3 {a2\pp <g b>1\mp}"
@@ -453,7 +466,8 @@ def test_staff_splitter_09():
                 }
             }
         >>
-        """)
+        """
+    )
 
 
 def test_staff_splitter_10():
@@ -504,7 +518,8 @@ def test_staff_splitter_10():
                 }
             }
         >>
-        """)
+        """
+    )
     staff = abjad.Staff(
         r"c'2\p <b d'>2\ff \times 2/3 {<g b d'>2\f <e' f'>1\mf}"
         r"\times 2/3 {a2\pp <g b>1\mp}"
@@ -550,7 +565,8 @@ def test_staff_splitter_10():
                 }
             }
         >>
-        """)
+        """
+    )
     staff = abjad.Staff(
         r"c'2\p <b d'>2\ff \times 2/3 {<g b d'>2\f <e' f'>1\mf}"
         r"\times 2/3 {a2\pp <g b>1\mp}"
@@ -598,7 +614,8 @@ def test_staff_splitter_10():
                 }
             }
         >>
-        """)
+        """
+    )
     staff = abjad.Staff(
         r"c'2\p <b d'>2\ff \times 2/3 {<g b d'>2\f <e' f'>1\mf}"
         r"\times 2/3 {a2\pp <g b>1\mp}"
@@ -647,7 +664,8 @@ def test_staff_splitter_10():
                 }
             }
         >>
-        """)
+        """
+    )
 
 
 def test_staff_splitter_11():
@@ -677,10 +695,66 @@ def test_staff_splitter_11():
                 r4
             }
         >>
-        """)
+        """
+    )
 
 
 def test_staff_splitter_12():
+    staff = abjad.Staff(
+        r"\time 2/4 a8( b c' d') \times 2/3 {<g b d'>2 <e' f'>4}"
+        r"\time 3/4 <d a c' g'>4--  r8 <f a bf>4."
+    )
+    staves = abjad.staff_splitter(staff)
+    score = abjad.Score(staves)
+    assert abjad.lilypond(score) == abjad.String.normalize(
+        r"""
+        \new Score
+        <<
+            \new Staff
+            {
+                \time 2/4
+                \clef "treble"
+                r4
+                c'8
+                (
+                d'8
+                )
+                \times 2/3
+                {
+                    d'2
+                    <e' f'>4
+                }
+                \time 3/4
+                <c' g'>4
+                - \tenuto
+                r2
+            }
+            \new Staff
+            {
+                \time 2/4
+                \clef "bass"
+                a8
+                (
+                b8
+                )
+                r4
+                \times 2/3
+                {
+                    <g b>2
+                    r4
+                }
+                \time 3/4
+                <d a>4
+                - \tenuto
+                r8
+                <f a bf>4.
+            }
+        >>
+        """
+    )
+
+
+def test_staff_splitter_13():
     staff = abjad.Staff(r"a4 b4 c'4 d'4")
     staves = abjad.staff_splitter(staff)
     score = abjad.Score(staves)
@@ -703,4 +777,5 @@ def test_staff_splitter_12():
                 r2
             }
         >>
-        """)
+        """
+    )
